import Vue from 'vue'

import echarts from 'echarts'
import Cookies from 'js-cookie'

import 'normalize.css/normalize.css' // a modern alternative to CSS resets
import '@/styles/index.scss' // global css

import App from './App'
import store from './store'
import router from './router'

import i18n from './lang' // internationalization
import './icons' // icon
import './permission' // permission control
import './utils/error-log' // error log

import * as filters from './filters' // global filters

import './plugins'

/* 全局安装[通用组件] */
import Layout from '@/components/layout'
import Constants from '@/constants/constants'

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online ! ! !
 */
if (process.env.NODE_ENV === 'production') {
  const { mockXHR } = require('../mock')
  mockXHR()
}

// register global utility filters
Object.keys(filters).forEach(key => {
  Vue.filter(key, filters[key])
})

Vue.config.productionTip = false
Vue.prototype.constants = Constants
Vue.prototype.HOME_URL = process.env.VUE_APP_BASE_API
Vue.prototype.$cookie = Cookies
Vue.prototype.$echarts = echarts

Vue.use(Layout)

new Vue({
  el: '#app',
  router,
  store,
  i18n,
  render: h => h(App)
})
